@@ -17,6 +17,8 @@
  *  GNU General Public License for more details.
  *
  */
+#include <config.h>
+
 #include "dates_callbacks.h"
 #include "dates_types.h"
 #include "dates_platform.h"
@@ -302,9 +304,9 @@ dates_date_changed_cb (DatesView *view, DatesData *d)
 #ifndef WITH_HILDON
     gchar *text;
 #endif
-	
+
     timem = icaltimetype_to_tm ((icaltimetype *)date);
-    strftime (buffer, 255, "%a, %F", &timem);
+    strftime (buffer, 255, "%A, %x", &timem);
 
 #ifdef WITH_HILDON
     gtk_window_set_title (GTK_WINDOW (d->main_window), buffer);
@@ -369,7 +371,7 @@ dates_about_cb (GtkWidget *widget, DatesData *d)
 			GTK_WINDOW (d->main_window),
 
 			"copyright",
-			"(c) 2006 OpenedHand Ltd",
+			"© 2006 - 2008 OpenedHand Ltd",
 
 #ifndef WITH_HILDON
 			"authors",
@@ -389,7 +391,7 @@ dates_about_cb (GtkWidget *widget, DatesData *d)
 			PACKAGE_VERSION,
 			
 			"website",
-			"http://www.pimlico-project.org/dates",
+			"http://www.pimlico-project.org/",
 			NULL);
 }
 
@@ -1760,6 +1762,7 @@ dates_import_calendar_data_from_file (ECal *cal, gchar *filename, GError **error
   GIOChannel *channel = NULL;
   gchar *line;
   gsize length;
+  gint num_comp_imported = 0;
 
   channel = g_io_channel_new_file (filename, "r", &tmp_error);
 
@@ -1811,7 +1814,9 @@ dates_import_calendar_data_from_file (ECal *cal, gchar *filename, GError **error
             g_free (uid);
             return FALSE;
           }
-
+					
+          num_comp_imported ++;
+          
           icalcompiter_next (&iter);
           g_free (uid);
         }
@@ -1835,8 +1840,17 @@ dates_import_calendar_data_from_file (ECal *cal, gchar *filename, GError **error
 
   if (channel)
     g_io_channel_unref (channel);
-
-  return TRUE;
+  
+  if (num_comp_imported > 0)
+  {
+    return TRUE;
+  }
+  else 
+  {
+    *error = g_error_new_literal
+      (g_quark_from_string ("Dates"), 1, _("No calendar events found."));
+    return FALSE;
+  }
 }
 
 void
@@ -1845,3 +1859,55 @@ dates_import_cb (GtkWidget *menu_item, gpointer user_data)
   dates_platform_import_dialog ((DatesData *)user_data);
 }
 
+
+static gboolean
+_zoom_to_event_cb (gpointer userdata)
+{
+	DatesData *data = (DatesData *)userdata;
+	static gint count = 0;
+
+	if (dates_view_set_selected_event (data->view,
+					   data->url_uid,
+					   NULL))
+	{
+		dates_fill_details_dialog (data->view, data);
+		dates_platform_details_dlg (data, TRUE);
+		g_free (data->url_uid);
+		count = 0;
+		return FALSE;
+	}
+
+	if (count > 5)
+	{
+		count = 0;
+		g_critical (G_STRLOC ": Unable to find event %s",
+			    data->url_uid);
+		g_free (data->url_uid);
+		return FALSE;
+	}
+
+	count++;
+	return TRUE;
+}
+
+gboolean
+dates_edit_event_on_startup (DatesData   *data,
+                             const gchar *url_uri_in)
+{
+	gchar **split_str;
+
+	split_str = g_strsplit (url_uri_in, " ", 2);
+
+	if (g_strv_length (split_str) != 2)
+	{
+		g_critical (G_STRLOC ": Unable to parse url_uid string: %s",
+			    url_uri_in);
+		return FALSE;
+	}
+
+	data->url_uid = g_strjoinv (NULL, split_str);
+	g_idle_add (_zoom_to_event_cb, data);
+	return TRUE;
+}
+
+
