@@ -176,4 +176,8 @@ dates_import_calendar_data_from_file (ECal *cal, gchar *filename,
 		GError **error);
 
 
+gboolean
+dates_edit_event_on_startup (DatesData   *data,
+                             const gchar *url_uri_in);
+
 #endif /* DATES_CALLBACKS_H */
